==> investr_1.2.0.tar.gz: investr/R/data.R <==
##' Crystal weight data
##' 
##' The data give the growing time and final weight of crystals.
##' 
##' \itemize{
##'   \item \code{time} Time taken to grow (hours).
##'   \item \code{weight} Final weight of the crystal (grams).
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 14 rows and 2 variables
##' @name crystal  
##' @source
##' Graybill, F. A., and Iyer, H. K. (1994)
##' \emph{Regression analysis: Concepts and Applications}. Duxbury Press.                       
NULL

##' Concentrations of arsenic in water samples
##' 
##' The data give the actual and measured concentrations of arsenic present in 
##' water samples.
##' 
##' \itemize{
##'   \item \code{actual} True amount of arsenic present.
##'   \item \code{measured} Measured amount of arsenic present.
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 32 rows and 2 variables
##' @name arsenic  
##' @source 
##' Graybill, F. A., and Iyer, H. K. (1994)
##' \emph{Regression analysis: Concepts and Applications}. Duxbury Press. 
NULL 

##' Bioassay on Nasturtium
##' 
##' The data give the actual concentrations of an agrochemical present in soil 
##' samples versus the weight of the plant after three weeks of growth. 
##' 
##' \itemize{
##'   \item \code{conc} True concentration of agrochemical (g/ha).
##'   \item \code{weight} Weight of plant (mg) after 3 weeks' growth.
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 42 rows and 2 variables
##' @name nasturtium  
##' @source 
##' Racine-Poon, A. (1988) A Bayesian Approach to Nonlinear Calibration 
##' Problems, \emph{Journal of the American Statistical Association}, \bold{83}, 
##' 650--656.
##' @references
##' Huet, S., Bouvier, A., Poursat, M-A., and Jolivet, E.  (2004)
##' \emph{Statistical Tools for Nonlinear Regression: A Practical Guide with 
##' S-PLUS and R Examples}. Springer. 
##' 
NULL

==> investr_1.3.0.tar.gz: investr/R/data.R <==
##' Crystal weight data
##' 
##' The data give the growing time and final weight of crystals.
##' 
##' \itemize{
##'   \item \code{time} Time taken to grow (hours).
##'   \item \code{weight} Final weight of the crystal (grams).
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 14 rows and 2 variables
##' @name crystal  
##' @source
##' Graybill, F. A., and Iyer, H. K. (1994)
##' \emph{Regression analysis: Concepts and Applications}. Duxbury Press.                       
NULL

##' Concentrations of arsenic in water samples
##' 
##' The data give the actual and measured concentrations of arsenic present in 
##' water samples.
##' 
##' \itemize{
##'   \item \code{actual} True amount of arsenic present.
##'   \item \code{measured} Measured amount of arsenic present.
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 32 rows and 2 variables
##' @name arsenic  
##' @source 
##' Graybill, F. A., and Iyer, H. K. (1994)
##' \emph{Regression analysis: Concepts and Applications}. Duxbury Press. 
NULL 

##' Bioassay on Nasturtium
##' 
##' The data give the actual concentrations of an agrochemical present in soil 
##' samples versus the weight of the plant after three weeks of growth. 
##' 
##' \itemize{
##'   \item \code{conc} True concentration of agrochemical (g/ha).
##'   \item \code{weight} Weight of plant (mg) after 3 weeks' growth.
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 42 rows and 2 variables
##' @name nasturtium  
##' @source 
##' Racine-Poon, A. (1988) A Bayesian Approach to Nonlinear Calibration 
##' Problems, \emph{Journal of the American Statistical Association}, \bold{83}, 
##' 650--656.
##' @references
##' Huet, S., Bouvier, A., Poursat, M-A., and Jolivet, E.  (2004)
##' \emph{Statistical Tools for Nonlinear Regression: A Practical Guide with 
##' S-PLUS and R Examples}. Springer. 
##' 
NULL 

##' Dobson's Beetle Data
##' 
##' The data give the number of flour beetles killed after five hour exposure 
##' to the insecticide carbon disulphide at eight different concentrations.
##' 
##' \itemize{
##'   \item \code{ldose} Log dose of carbon disulphide.
##'   \item \code{y} Number of beetles subjected to insecticide.
##'   \item \code{n} Number of beetles killed.
##' }
##' @docType data
##' @keywords datasets
##' @format A data frame with 8 rows and 3 variables
##' @name beetle  
##' @source 
##' A. Dobson, \emph{An Introduction to Generalized Linear Models}, Chapman & 
##' Hall/CRC, 2002.
##'
NULL
